@@ -10,6 +10,6 @@ let cCAMLtoTKbindings = function
 
 (* this doesn't really belong here *)
 let cTKtoCAMLbindings s =
-  if String.length s > 0 & s.[0] = '.' then
+  if String.length s > 0 && s.[0] = '.' then
     WidgetBindings (cTKtoCAMLwidget s)
   else TagBindings s
