@@ -1,5 +1,5 @@
 let bind widget tag eventsequence action =
-  tkEval [| cCAMLtoTKwidget widget_canvas_table widget;
+  tkCommand [| cCAMLtoTKwidget widget_canvas_table widget;
       	    TkToken "bind";
       	    cCAMLtoTKtagOrId tag;
        	    cCAMLtoTKeventSequence eventsequence;
@@ -17,5 +17,4 @@ let bind widget tag eventsequence action =
       let cbId = register_callback widget (wrapeventInfo f what) in
         TkToken ("+camlcb " ^ cbId ^ (writeeventField what))
 
-  end |];
-  ()
+  end |]
