@@ -5,6 +5,5 @@ let idle f =
     clear_callback id; (* do it first in case f raises exception *)
     f() in
   Hashtbl.add callback_naming_table id wrapped;
-    tkEval [| TkToken "after"; TkToken "idle";
-      	      TkToken ("camlcb "^ string_of_cbid id) |];
-    ()
+    tkCommand [| TkToken "after"; TkToken "idle";
+      	         TkToken ("camlcb "^ string_of_cbid id) |]
