@@ -9,9 +9,8 @@ let register name f =
   (* For rpc_info *)
   Textvariable.set (Textvariable.coerce ("camltkrpc("^name^")"))
                    (string_of_cbid id);
-  tkEval [| TkToken "proc"; TkToken name; TkToken "args";
-      	    TkToken ("camlcb "^(string_of_cbid id)^" $args") |];
-  ()
+  tkCommand [| TkToken "proc"; TkToken name; TkToken "args";
+      	    TkToken ("camlcb "^(string_of_cbid id)^" $args") |]
 
 (* RPC *)
 let invoke interp f args =
@@ -23,14 +22,13 @@ let invoke interp f args =
     |]
 
 let async_invoke interp f args =
-  tkEval [|
+  tkCommand [|
     TkToken "send";
     TkToken "-async";
     TkToken interp;
     TkToken f;
     TkTokenList (List.map (fun s -> TkToken s) args)
-    |];
-  ()
+    |]
 
 let rpc_info interp =
   tkEval [|
