@@ -3,7 +3,7 @@
  *)
 external tcl_eval : string -> string
       	=  "camltk_tcl_eval"
-
+let tcl_command s = ignore (tcl_eval s);;
 open Printf
 
 let dynload args =
@@ -19,7 +19,7 @@ let init () =
   Dynlink.allow_unsafe_modules true;
   Dynlink.add_interfaces [] []
   let s = register_callback Widget.dummy dynload in
-  tcl_eval (sprintf "proc caml::run {l} {camlcb %s l}" s)
+  tcl_command (sprintf "proc caml::run {l} {camlcb %s l}" s)
 
 let _ =
   Printexc.print init ()
